summaryrefslogtreecommitdiff
path: root/tools/driver/driver.cpp
diff options
context:
space:
mode:
authorBob Wilson <bob.wilson@apple.com>2014-01-15 01:41:52 +0000
committerBob Wilson <bob.wilson@apple.com>2014-01-15 01:41:52 +0000
commitb13e4cc99ed63a38db9a72b2d84af882ac7172cf (patch)
tree6159374b05af6f6bcf3f2aa4cfde179e99266002 /tools/driver/driver.cpp
parentd26b54441b8af5475b37f8a948b75c8cec8a8cdf (diff)
downloadclang-b13e4cc99ed63a38db9a72b2d84af882ac7172cf.tar.gz
clang-b13e4cc99ed63a38db9a72b2d84af882ac7172cf.tar.bz2
clang-b13e4cc99ed63a38db9a72b2d84af882ac7172cf.tar.xz
Rename QA_OVERRIDE_GCC3_OPTIONS to CCC_OVERRIDE_OPTIONS. <rdar://14578381>
Continue to accept the old name for a while to make it an easier transition for people who rely on this. git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@199283 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'tools/driver/driver.cpp')
-rw-r--r--tools/driver/driver.cpp12
1 files changed, 8 insertions, 4 deletions
diff --git a/tools/driver/driver.cpp b/tools/driver/driver.cpp
index 12feb36e7b..8acd9b378c 100644
--- a/tools/driver/driver.cpp
+++ b/tools/driver/driver.cpp
@@ -169,7 +169,7 @@ static void ApplyQAOverride(SmallVectorImpl<const char*> &Args,
OS = &llvm::nulls();
}
- *OS << "### QA_OVERRIDE_GCC3_OPTIONS: " << OverrideStr << "\n";
+ *OS << "### CCC_OVERRIDE_OPTIONS: " << OverrideStr << "\n";
// This does not need to be efficient.
@@ -330,11 +330,15 @@ int main(int argc_, const char **argv_) {
}
}
- // Handle QA_OVERRIDE_GCC3_OPTIONS and CCC_ADD_ARGS, used for editing a
- // command line behind the scenes.
- if (const char *OverrideStr = ::getenv("QA_OVERRIDE_GCC3_OPTIONS")) {
+ // Handle CCC_OVERRIDE_OPTIONS, used for editing a command line behind the
+ // scenes. Temporarily accept the old QA_OVERRIDE_GCC3_OPTIONS name
+ // for this, to ease the transition. FIXME: Remove support for that old name
+ // after a while.
+ if (const char *OverrideStr = ::getenv("CCC_OVERRIDE_OPTIONS")) {
// FIXME: Driver shouldn't take extra initial argument.
ApplyQAOverride(argv, OverrideStr, SavedStrings);
+ } else if (const char *OverrideStr = ::getenv("QA_OVERRIDE_GCC3_OPTIONS")) {
+ ApplyQAOverride(argv, OverrideStr, SavedStrings);
}
std::string Path = GetExecutablePath(argv[0], CanonicalPrefixes);